Adc

Struct Adc 

pub struct Adc<'d, ADCX, Dm: DriverMode> { /* private fields */ }
Available on crate feature unstable only.
Analog-to-Digital Converter peripheral driver.

Implementations

Source

impl<'d, ADCX> Adc<'d, ADCX, Blocking>
where ADCX: RegisterAccess + 'd,

pub fn new(adc_instance: ADCX, config: AdcConfig<ADCX>) -> Self

Configures a given ADC instance using the provided configuration, and initializes the ADC for use.

pub fn into_async(self) -> Adc<'d, ADCX, Async>

Reconfigures the ADC driver to operate in asynchronous mode.

pub fn read_oneshot<PIN, CS>( &mut self, pin: &mut AdcPin<PIN, ADCX, CS>, ) -> Result<u16, ()>
where PIN: AdcChannel, CS: AdcCalScheme<ADCX>,

Requests that the ADC begin a conversion on the specified pin.

Takes an AdcPin reference, as it is expected that the ADC will be able to sample whatever channel underlies the pin.

Source

impl<'d, ADCX> Adc<'d, ADCX, Async>
where ADCX: RegisterAccess + 'd,

pub fn into_blocking(self) -> Adc<'d, ADCX, Blocking>

Reconfigures the ADC driver to operate in Blocking mode.

pub async fn read_oneshot<PIN, CS>( &mut self, pin: &mut AdcPin<PIN, ADCX, CS>, ) -> u16
where ADCX: Instance, PIN: AdcChannel, CS: AdcCalScheme<ADCX>,

Requests that the ADC begin a conversion on the specified pin.

Takes an AdcPin reference, as it is expected that the ADC will be able to sample whatever channel underlies the pin.